from allensdk.model.biophys_sim.neuron.hoc_utils import HocUtils
import logging


class Utils(HocUtils):
    _log = logging.getLogger(__name__)
    
    def __init__(self, description):
        super(Utils, self).__init__(description)
        self.stim = None
        self.stim_curr = None
        self.sampling_rate = None
    
    def generate_morphology(self):
        h = self.h
        self.soma = h.Section()
        self.soma.L = 10.0
        self.soma.diam = 10.0
    
    def load_cell_parameters(self):
        passive = self.description.data['passive'][0]
        channel_parameters = self.description.data['channel_parameters'][0]
        conditions = self.description.data['conditions'][0]
        
        # Insert channels
        self.soma.insert('pas')
        self.soma.insert('NaTs')
        self.soma.insert('K_P')

        # Set fixed passive properties
        self.soma.Ra = passive['ra']
        self.soma.cm = passive["cm"]
        for seg in self.soma:
            seg.pas.e = passive["e_pas"]
            seg.pas.g = channel_parameters["g_pas"]
        
        # Set active channel densities
        for seg in self.soma:
            seg.NaTs.gbar = channel_parameters["gbar_Na"]
            seg.K_P.gbar = channel_parameters["gbar_K"]
        
        # Set reversal potentials
        self.soma.ena = conditions["erev"][0]["ena"]
        self.soma.ek = conditions["erev"][0]["ek"]

    def setup_iclamp(self):
        self.stim = self.h.IClamp(self.soma(0.5))
        self.stim.amp = 0.1
        self.stim.delay = 5.0
        self.stim.dur = 2.0

    def record_values(self):
        vec = { "v": self.h.Vector(),
                "t": self.h.Vector() }
    
        vec["v"].record(self.soma(0.5)._ref_v)
        vec["t"].record(self.h._ref_t)
    
        return vec
        